from setuptools import setup, find_packages

setup(
  name='sq-notebook-shutdown',
  version="0.0.1",
  description='This is used as a placeholder to help prevent dependency confusion attacks.',
  author='SorryNotSorry',
  author_email='dependency.placeholder@block.xyz',
  python_requires=">=3.10",
  packages=find_packages()
)
